@@ -53,23 +53,25 @@ class Client(object):
         return self._parse(client.post(self.url + endpoint, data=data, verify=True))
 
     def _parse(self, response):
-        if response.status_code == requests.codes.not_found:
-            raise exception.InvalidURL(response.url)
-        if response.status_code != requests.codes.ok:
-            raise exception.UnknownError()
+        if 'application/json' in response.headers['Content-Type']:
+            r = response.json()
+        else:
+            try:
+                r = response.json() # Una version anterior de SugarCRM no utiliza los headers adecuadamente.
+            except Exception:
+                r = response.text
 
-        data = response.json()
-        if 'name' in data and 'description' in data and 'number' in data:
-            code = data['number']
-            message = data['description']
+        if 'name' in r and 'description' in r and 'number' in r:
+            code = r['number']
+            message = r['description']
 
             try:
                 error_enum = ErrorEnum(code)
             except Exception:
-                raise exception.UnexpectedError('Error: {}. Message {}'.format(code, message))
+                raise exception.UnknownError('Error: {}. Message {}'.format(code, message))
             if error_enum == ErrorEnum.InvalidLogin:
                 raise exception.InvalidLogin(message)
-        return data
+        return r
 
     def get_available_modules(self, filter='default'):
         """Retrieves a list of available modules in the system.
@@ -140,7 +142,7 @@ class Client(object):
         if link_name_to_fields_array:
             link_name_to_fields_array = [{'name': k.lower(), 'value': v} for k, v in link_name_to_fields_array.items()]
         data = [self.session_id, module_name, id, select_fields, link_name_to_fields_array, track_view]
-        return self._post('get_entries_count', data)
+        return self._post('get_entry', data)
 
     @valid_parameters
     def get_entry_list(self, module_name, *, query="", order_by="", offset=0, select_fields=[],
